pub struct ExternalAuthAuthorizationStart {
pub authorization_url: String,
pub state: String,
pub nonce: Option<String>,
pub pkce_verifier: Option<String>,
}Expand description
Result of starting an authorization flow.
Fields
Provider authorization URL to redirect the browser to.
state: StringCSRF state stored by the application for callback validation.
nonce: Option<String>Optional OIDC nonce stored by the application for callback validation.
pkce_verifier: Option<String>Optional PKCE verifier stored by the application for callback exchange.